@@ -64,7 +64,9 @@ class QuicTlsSettings:
     """The certificate to use for the connection."""
     certificate_chain: list[x509.Certificate] = field(default_factory=list)
     """A list of additional certificates to send to the peer."""
-    certificate_private_key: dsa.DSAPrivateKey | ec.EllipticCurvePrivateKey | rsa.RSAPrivateKey | None = None
+    certificate_private_key: (
+        dsa.DSAPrivateKey | ec.EllipticCurvePrivateKey | rsa.RSAPrivateKey | None
+    ) = None
     """The certificate's private key."""
     cipher_suites: list[CipherSuite] | None = None
     """An optional list of allowed/advertised cipher suites."""
@@ -481,9 +483,9 @@ class QuicStreamLayer(layer.Layer):
             else:
                 break  # pragma: no cover
         if isinstance(child_layer, (UDPLayer, TCPLayer)) and child_layer.flow:
-            child_layer.flow.metadata[
-                "quic_is_unidirectional"
-            ] = stream_is_unidirectional(self._client_stream_id)
+            child_layer.flow.metadata["quic_is_unidirectional"] = (
+                stream_is_unidirectional(self._client_stream_id)
+            )
             child_layer.flow.metadata["quic_initiator"] = (
                 "client"
                 if stream_is_client_initiated(self._client_stream_id)
