@@ -3,7 +3,8 @@ import logging
 from collections.abc import Sequence
 
 import mitmproxy.types
-from mitmproxy import command, command_lexer
+from mitmproxy import command
+from mitmproxy import command_lexer
 from mitmproxy import contentviews
 from mitmproxy import ctx
 from mitmproxy import dns
@@ -374,7 +375,9 @@ class ConsoleAddon:
         flow = self.master.view.focus.flow
         focus_options = []
 
-        if isinstance(flow, tcp.TCPFlow):
+        if flow is None:
+            raise exceptions.CommandError("No flow selected.")
+        elif isinstance(flow, tcp.TCPFlow):
             focus_options = ["tcp-message"]
         elif isinstance(flow, udp.UDPFlow):
             focus_options = ["udp-message"]
